@@ -7,11 +7,11 @@ class UnsupportedSislType(Exception):
 class SISLTypeFlatten:
     @classmethod
     def flatten(cls, sisl_dict):
+        for (key, type_value) in sisl_dict.items():
+            if key == "_" and "_" in type_value["type"]:
+                return cls._lookup_type_cast(type_value)
         return {key: cls._lookup_type_cast(type_value) for key, type_value in sisl_dict.items()}
 
-    @classmethod
-    def _flatten_to_list(cls, sisl_dict):
-        return [cls._lookup_type_cast(value) for key, value in sisl_dict.items()]
 
     @classmethod
     def _lookup_type_cast(cls, type_value):
@@ -21,14 +21,25 @@ class SISLTypeFlatten:
     def _type_cast_mappings(cls):
         return {
             "str": cls._convert_string,
+            "_str": cls._convert_string,
             "obj": lambda type_value: cls.flatten(type_value["value"]),
+            "_obj": lambda type_value: cls.flatten(type_value["value"]),
             "bool": cls._convert_bool,
+            "_bool": cls._convert_bool,
             "int": lambda type_value: int(type_value["value"]),
+            "_int": lambda type_value: int(type_value["value"]),
             "float": lambda type_value: float(type_value["value"]),
+            "_float": lambda type_value: float(type_value["value"]),
             "list": lambda type_value: cls._flatten_to_list(type_value["value"]),
-            "null": lambda type_value: None
+            "_list": lambda type_value: cls._flatten_to_list(type_value["value"]),
+            "null": lambda type_value: None,
+            "_null": lambda type_value: None
         }
 
+    @classmethod
+    def _flatten_to_list(cls, sisl_dict):
+        return [cls._lookup_type_cast(value) for key, value in sisl_dict.items()]
+
     @staticmethod
     def _convert_string(type_value):
         return str(type_value['value']).replace(r'\"', r'"').encode().decode('unicode_escape')
