@@ -8,9 +8,10 @@ from pysisl.deep_merger import ListTuple
 class ExplodeStructureTests(unittest.TestCase):
 
     def test_explode_structure_for_flat_list(self):
+        # {"field_one": ["I"]}
         self.assertEqual([{"field_one": [ListTuple("I", 0)]}],
                          ExplodeStructure.explode_structure({"field_one": [ListTuple("I", 0)]}))
-
+        # {"field_one": ["I", "am", "a", "list"]}
         self.assertEqual([{"field_one": [ListTuple("I", 0)]},
                           {"field_one": [ListTuple("I", 0), ListTuple("am", 1)]},
                           {"field_one": [ListTuple("I", 0), ListTuple("am", 1), ListTuple("a", 2)]},
@@ -22,6 +23,22 @@ class ExplodeStructureTests(unittest.TestCase):
         self.assertEqual([{"field_one": "value_1"}, {"field_one": "value_1", "field_two": "value_2"}],
                          ExplodeStructure.explode_structure({"field_one": "value_1", "field_two": "value_2"}))
 
+    def test_anonymous_string(self):
+        # "string"
+        self.assertEqual(["string"], ExplodeStructure.explode_structure("string"))
+
+    def test_anonymous_bool(self):
+        # True
+        self.assertEqual([True], ExplodeStructure.explode_structure(True))
+
+    def test_anonymous_int(self):
+        # 1
+        self.assertEqual([1], ExplodeStructure.explode_structure(1))
+
+    def test_anonymous_list(self):
+        # [1, 2]
+        self.assertEqual([[ListTuple(1, 0)], [ListTuple(1, 0), ListTuple(2, 1)]], ExplodeStructure.explode_structure([1, 2]))
+
     def test_explode_structure_for_nested_list(self):
         # {"field_one": ["item_1", ["item_2"]]}
         self.assertEqual([{"field_one": [ListTuple("item_1", 0)]},
